/*
 Repeating Web client

 This sketch connects to a web server and makes a request
 using a WIZnet Ethernet shield. You can use the Arduino Ethernet Shield, or
 the Adafruit Ethernet shield, either one will work, as long as it's got
 a WIZnet Ethernet module on board.

 This example uses DNS, by assigning the Ethernet client with a MAC address,
 IP address, and DNS address.

 Circuit:
 * Ethernet shield attached to pins 10, 11, 12, 13

 created 19 Apr 2012
 by Tom Igoe
 modified 21 Jan 2014
 by Federico Vanzati

 https://www.arduino.cc/en/Tutorial/WebClientRepeating
 This code is in the public domain.

 */

#include <SPI.h>
#include <Ethernet.h>


// assign a MAC address for the Ethernet controller.
// fill in your address here:
byte mac[] = {
  0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED
};
// Set the static IP address to use if the DHCP fails to assign
//IPAddress ip(192, 168, 1, 177);
//IPAddress myDns(192, 168, 1, 1);

IPAddress ip(192, 168, 0, 177);
IPAddress myDns(192, 168, 0, 1);

// initialize the library instance:
EthernetClient client;

//char server[] = "192.168.1.17";  // also change the Host line in httpRequest()
char server[] = "trinityautomations.com";  // also change the Host line in httpRequest()
//IPAddress server(64,131,82,241);

unsigned long lastConnectionTime = 0;           // last time you connected to the server, in milliseconds
const unsigned long postingInterval = 10*1000;  // delay between updates, in milliseconds

void setup() {
  pinMode(5, OUTPUT);
  pinMode(6, OUTPUT);
  pinMode(7, OUTPUT);
  pinMode(8, OUTPUT);
  pinMode(9, OUTPUT);
  // You can use Ethernet.init(pin) to configure the CS pin
  Ethernet.init(10);  // Most Arduino shields
  //Ethernet.init(5);   // MKR ETH Shield
  //Ethernet.init(0);   // Teensy 2.0
  //Ethernet.init(20);  // Teensy++ 2.0
  //Ethernet.init(15);  // ESP8266 with Adafruit FeatherWing Ethernet
  //Ethernet.init(33);  // ESP32 with Adafruit FeatherWing Ethernet

  // start serial port:
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }

  // start the Ethernet connection:
  Serial.println("Initialize Ethernet with DHCP:");
  if (Ethernet.begin(mac) == 0) {
    Serial.println("Failed to configure Ethernet using DHCP");
    // Check for Ethernet hardware present
    if (Ethernet.hardwareStatus() == EthernetNoHardware) {
      Serial.println("Ethernet shield was not found.  Sorry, can't run without hardware. :(");
      while (true) {
        delay(1); // do nothing, no point running without Ethernet hardware
      }
    }
    if (Ethernet.linkStatus() == LinkOFF) {
      Serial.println("Ethernet cable is not connected.");
    }
    // try to configure using IP address instead of DHCP:
    Ethernet.begin(mac, ip, myDns);
    Serial.print("My IP address: ");
    Serial.println(Ethernet.localIP());
  } else {
    Serial.print("  DHCP assigned IP ");
    Serial.println(Ethernet.localIP());
  }
  // give the Ethernet shield a second to initialize:
  delay(1000);
}

void loop() {
  // if there's incoming data from the net connection.
  // send it out the serial port.  This is for debugging
  // purposes only:
  
  if (client.available()) {

  char c = client.read();
  
    //Serial.write(c);
    Serial.print(c);
    switch (c) {
    case '5':  // your hand is on the sensor
      Serial.print("5");
      c = client.read();
      Serial.print(c);
     if(c == '1'){
       Serial.print("pin 5 HIGH");
      digitalWrite(5, HIGH);
    }
    else {
      Serial.print("pin 5 low");
      digitalWrite(5, LOW); 
    }
      break;
    case '6':  // your hand is close to the sensor
      Serial.print("6");
      c = client.read();
      Serial.print(c);
     if(c == '1'){
       Serial.print("pin 6 HIGH");
      digitalWrite(6, HIGH);
    }
    else {
      Serial.print("pin 6 low");
      digitalWrite(6, LOW); 
    }
      break;
    case '7':  // your hand is a few inches from the sensor
      Serial.print("7");
      c = client.read();
      Serial.print(c);
     if(c == '1'){
       Serial.print("pin 7 HIGH");
      digitalWrite(7, HIGH);
    }
    else {
      Serial.print("pin 7 low");
      digitalWrite(7, LOW); 
    }
      break;
    case '8':  // your hand is nowhere near the sensor
      Serial.print("8");
      c = client.read();
      Serial.print(c);
     if(c == '1'){
       Serial.print("pin 8 HIGH");
      digitalWrite(8, HIGH);
    }
    else {
      Serial.print("pin 8 low");
      digitalWrite(8, LOW); 
    }
      break;
    case '9':  // your hand is nowhere near the sensor
      Serial.print("9");
      c = client.read();
      Serial.print(c);
     if(c == '1'){
       Serial.print("pin 9 HIGH");
      digitalWrite(9, HIGH);
    }
    else {
      Serial.print("pin 9 low");
      digitalWrite(9, LOW); 
    }
      break;  
  }
    
   
  }

  

  // if ten seconds have passed since your last connection,
  // then connect again and send data:
 
  if (millis() - lastConnectionTime > postingInterval) {
    //delay(10000);
    httpRequest();
  } 
 
}

// this method makes a HTTP connection to the server:
void httpRequest() {
  // close any connection before send a new request.
  // This will free the socket on the Ethernet shield
  client.stop();
  
  // if there's a successful connection:
  if (client.connect(server, 80)) {
    Serial.println("connecting...");
    // send the HTTP GET request:
    String out_http_reque_1 = "GET /clienttest/index.php?fname1=";
    int out_http_reque_2 = analogRead(A0); 
    String out_http_reque_3 = "&fname2=";
    int out_http_reque_4 = analogRead(A1); 
    String out_http_reque_5 = " HTTP/1.1";
    String out_http_reque = out_http_reque_1 + out_http_reque_2 + out_http_reque_3 + out_http_reque_4 + out_http_reque_5;
    //client.println("GET /clienttest/index.php?fname=+channel_01+ HTTP/1.1");
    client.println(out_http_reque);
    client.println("Host: trinityautomations.com");
    //client.println("Host: 192.168.1.17");
    //client.println("User-Agent: arduino-ethernet");
    client.println("Connection: close");
    client.println();

    // note the time that the connection was made:
    lastConnectionTime = millis();
  } else {
    // if you couldn't make a connection:
    Serial.println("connection failed");
  }
  
}
